@@ -2,8 +2,9 @@ from arcor2.data.rpc import common
 from arcor2.data.rpc import execution
 from arcor2.data.rpc import objects
 from arcor2.data.rpc import robot
-from arcor2.data.rpc import scene_project
+from arcor2.data.rpc import scene
+from arcor2.data.rpc import project
 from arcor2.data.rpc import services
 from arcor2.data.rpc import storage
 
-__all__ = ["common", "execution", "objects", "robot", "scene_project", "services", "storage"]
+__all__ = ["common", "execution", "objects", "robot", "scene", "project", "services", "storage"]
